pub struct vaddr64(u64);Expand description
address types vaddr64 and paddr64 have the same underlying type u64; We make the explicit distinction to avoid stupid errors.
Tuple Fields
0: u64pub struct vaddr64(u64);address types vaddr64 and paddr64 have the same underlying type u64; We make the explicit distinction to avoid stupid errors.
0: u64